@@ -60,12 +60,8 @@ pub mod example {
     //!     }
     //!
     //!     dep_obj! {
-    //!         pub fn obj(self as this, app: MyApp) -> MyDepType {
-    //!             if mut {
-    //!                 &mut app.my_dep_types[this.0].dep_data
-    //!             } else {
-    //!                 &app.my_dep_types[this.0].dep_data
-    //!             }
+    //!         pub fn obj(self as this, app: MyApp) -> &mut MyDepType {
+    //!             &mut app.my_dep_types[this.0].dep_data
     //!         }
     //!     }
     //! }
@@ -109,12 +105,8 @@ pub mod example {
         }
 
         dep_obj! {
-            pub fn obj(self as this, app: MyApp) -> MyDepType {
-                if mut {
-                    &mut app.my_dep_types[this.0].dep_data
-                } else {
-                    &app.my_dep_types[this.0].dep_data
-                }
+            pub fn obj(self as this, app: MyApp) -> &mut MyDepType {
+                &mut app.my_dep_types[this.0].dep_data
             }
         }
     }
@@ -268,12 +260,8 @@ impl<ItemType: Convenient> DepVecEntry<ItemType> {
 ///     }
 ///
 ///     dep_obj! {
-///         pub fn obj(self as this, app: MyApp) -> MyDepType {
-///             if mut {
-///                 &mut app.my_dep_types[this.0].dep_data
-///             } else {
-///                 &app.my_dep_types[this.0].dep_data
-///             }
+///         pub fn obj(self as this, app: MyApp) -> &mut MyDepType {
+///             &mut app.my_dep_types[this.0].dep_data
 ///         }
 ///     }
 /// }
@@ -521,7 +509,7 @@ impl<'a, 'b, Owner: DepType, Arena: 'static, PropType: Convenient> DepObjProp<'a
         let old = entry_mut.local.as_ref()
             .or_else(|| entry_mut.style.as_ref())
             .unwrap_or_else(|| entry_mut.default)
-            ;
+        ;
         if &value == old { return; }
         let old = entry_mut.local.replace(value.clone()).unwrap_or_else(||
             entry_mut.style.as_ref().unwrap_or_else(|| entry_mut.default).clone()
@@ -1142,7 +1130,7 @@ macro_rules! dep_type_impl_raw {
                     $vis fn $field(mut self, value: $field_ty) -> Self {
                         let id = <$BuilderCore as $crate::DepObjBuilderCore<$Id>>::id(&self.core);
                         let state = <$BuilderCore as $crate::DepObjBuilderCore<$Id>>::state_mut(&mut self.core);
-                        id. [< $obj _mut >] (state).set_uncond($name:: [< $field:upper >] , value);
+                        id. $obj (state).set_uncond($name:: [< $field:upper >] , value);
                         self
                     }
                 ]
@@ -1311,8 +1299,8 @@ macro_rules! dep_type_impl_raw {
 #[macro_export]
 macro_rules! dep_obj {
     (
-        $vis:vis fn $name:ident (self as $this:ident, $arena:ident : $Arena:ty) -> dyn $ty:tt {
-            if mut { $field_mut:expr } else { $field:expr }
+        $vis:vis fn $name:ident (self as $this:ident, $arena:ident : $Arena:ty) -> &mut dyn $ty:tt {
+            $field_mut:expr
         }
     ) => {
         $crate::paste_paste! {
@@ -1333,8 +1321,8 @@ macro_rules! dep_obj {
         }
     };
     (
-        $vis:vis fn $name:ident (self as $this:ident, $arena:ident: $Arena:ty) -> $ty:ty {
-            if mut { $field_mut:expr } else { $field:expr }
+        $vis:vis fn $name:ident (self as $this:ident, $arena:ident: $Arena:ty) -> &mut $ty:ty {
+            $field_mut:expr
         }
     ) => {
         $crate::paste_paste! {
